@@ -33,7 +33,7 @@ To see which command line options are available:
 
     $python -m arjuna -h
 
-All classes, functions and names supposed to be used in test automation code are available in Tester Programming Interface: `arjuna.tpi` package.
+All classes, functions and names supposed to be used in test automation code are available in Tester Programming Interface: **arjuna.tpi** package.
 """
 
 import pkg_resources
@@ -72,22 +72,25 @@ class _ArjunFacade:
         cli.execute()
 
 from arjuna.tpi.engine import Arjuna
-from arjuna.tpi.hook.pytest import PytestHooks
 from arjuna.tpi.engine.test import *
 from arjuna.tpi.engine.relation import *
-from arjuna.tpi.engine.fixture import *
+from arjuna.tpi.engine.resource import *
 from arjuna.tpi.tracker import track
 from arjuna.tpi.engine.data.markup import *
 from arjuna.tpi.engine.data.record import *
-from arjuna.tpi.engine.data.generator import Random, DataEntity, Locales
+from arjuna.tpi.engine.data.generator import Random, Locales
+from arjuna.tpi.engine.data.entity import data_entity, DataEntity
 
-from arjuna.tpi.helper.arjtype import NVPair, NVPairs, Screen, Attr, Point, Offset
+from arjuna.tpi.helper.arjtype import NVPair, NVPairs, Screen, Attr, Point, Offset, NetworkPacketInfo
 from arjuna.tpi.guiauto.meta.locator import GuiWidgetLocator
 from arjuna.tpi.guiauto.model.app import GuiApp
 from arjuna.tpi.guiauto.model.page import GuiPage
 from arjuna.tpi.guiauto.model.section import GuiSection
 from arjuna.tpi.guiauto.model.dialog import GuiDialog
 
+from arjuna.tpi.httpauto.session import HttpSession
+from arjuna.tpi.httpauto.oauth import OAuthImplicitGrantSession
+
 from arjuna.tpi.error import *
 from arjuna.tpi.constant import *
 from arjuna.core.constant import *
