@@ -319,4 +319,50 @@ class GuiWidgetType(Enum):
 class DryRunType(Enum):
     SHOW_TESTS = auto()
     SHOW_PLAN = auto()
-    RUN_FIXTURES = auto()
\ No newline at end of file
+    CREATE_RES = auto()
+
+class BuiltInProp(Enum):
+    PACKAGE = auto()
+    MODULE = auto()
+    QUAL_NAME = auto()
+    ID = auto()
+    PRIORITY = auto()
+    THREADS= auto()
+    NAME = auto()
+    AUTHOR = auto()
+    IDEA = auto()
+    UNSTABLE = auto()
+    COMPONENT = auto()
+    APP_VERSION = auto()
+    LEVEL = auto()
+    REVIEWED = auto()
+
+class RuleNature(Enum):
+    INCLUDE = auto()
+    EXCLUDE = auto()
+
+class RuleType(Enum):
+    SET = auto()
+    DICT_KEY = auto()
+    DICT_VALUE = auto()
+
+class RuleTargetType(Enum):
+    PROPS = auto()
+    TAGS = auto()
+    BUGS = auto()
+
+class RuleConditionType(Enum):
+    EQUAL = auto()
+    NOT_EQUAL = auto()
+    MATCHES = auto()
+    DOES_NOT_MATCH = auto()
+    PARTIALLY_MATCHES = auto()
+    DOES_NOT_PARTIALLY_MATCH = auto()
+    LESS_THAN = auto()
+    LESS_OR_EQUAL = auto()
+    GREATER_THAN = auto()
+    GREATER_OR_EQUAL = auto()
+    CONTAINS = auto()
+    IS_SUBSET = auto()
+    HAS_INTERSECTION = auto()
+    NO_INTERSECTION = auto()
