@@ -22,7 +22,7 @@ from .reference import ContextualDataReference
 from arjuna.tpi.helper.arjtype import CIStringDict
 
 from arjuna.core.utils import file_utils
-from arjuna.tpi.helper.json import Json
+from arjuna.tpi.helper.json import Json, JsonDict
 
 class L10NRef:
 
@@ -32,13 +32,13 @@ class L10NRef:
     def update_from_excel_ref(self, localizer_ref):
         for lang, record in localizer_ref.map.items():
             if lang not in self.map:
-                self.map[lang] = Json()
+                self.map[lang] = JsonDict()
             self.map[lang].update(record.named_values)
 
     def update_from_json_ref(self, json_ref):
         for lang, map in json_ref.map.items():
             if lang not in self.map:
-                self.map[lang] = Json()
+                self.map[lang] = JsonDict()
             self.map[lang].update(map)
 
     def lang(self, lang):
@@ -158,24 +158,26 @@ class Localizer:
         l10n_excel_dir = ref_config.value(ArjunaOption.L10N_EXCEL_DIR)
         l10n_merged_ref = L10NRef()
         l10n_refs = Localizers()
-        fnames = os.listdir(l10n_excel_dir)
-        fnames.sort()
-        for fname in fnames:
-            if fname.lower().endswith("xls"):
-                ref = ExcelL10NRef(os.path.join(l10n_excel_dir, fname))
-                l10n_merged_ref.update_from_excel_ref(ref)
-                l10n_refs[os.path.splitext(fname)[0]] = ref
+        if os.path.isdir(l10n_excel_dir):
+            fnames = os.listdir(l10n_excel_dir)
+            fnames.sort()
+            for fname in fnames:
+                if fname.lower().endswith("xls"):
+                    ref = ExcelL10NRef(os.path.join(l10n_excel_dir, fname))
+                    l10n_merged_ref.update_from_excel_ref(ref)
+                    l10n_refs[os.path.splitext(fname)[0]] = ref
 
         # JSON Localizers
         l10n_json_dir = ref_config.value(ArjunaOption.L10N_JSON_DIR)
-        json_ref = JsonL10NRef(l10n_json_dir)
-        cls.__process_json_ref(l10n_merged_ref, l10n_refs, json_ref, bucket="root")
-        buckets = os.listdir(l10n_json_dir)
-        for bucket in buckets:
-            if os.path.isdir(os.path.join(l10n_json_dir, bucket)):
-                dpath = os.path.join(l10n_json_dir, bucket)
-                json_ref = JsonL10NRef(dpath)
-                cls.__process_json_ref(l10n_merged_ref, l10n_refs, json_ref, bucket=bucket)
+        if os.path.isdir(l10n_json_dir):
+            json_ref = JsonL10NRef(l10n_json_dir)
+            cls.__process_json_ref(l10n_merged_ref, l10n_refs, json_ref, bucket="root")
+            buckets = os.listdir(l10n_json_dir)
+            for bucket in buckets:
+                if os.path.isdir(os.path.join(l10n_json_dir, bucket)):
+                    dpath = os.path.join(l10n_json_dir, bucket)
+                    json_ref = JsonL10NRef(dpath)
+                    cls.__process_json_ref(l10n_merged_ref, l10n_refs, json_ref, bucket=bucket)
 
         # l10n_merged_ref.enumerate()
         return Localizer(l10n_merged_ref, l10n_refs)
@@ -199,11 +201,8 @@ def L(in_str, *, locale=None, bucket=None, strict=None):
             val = Arjuna.get_localizer().globals.lang(lang)[query]
         else:
             val = Arjuna.get_localizer().buckets[bucket].lang(lang)[query]
-        if type(val) in {list, tuple}:
-            if not val:
-                raise Exception("No localized string found for: {} for Locale.{}".format(in_str, lang.upper()))
-            else:
-                return val[0]
+        if not val:
+            raise Exception("No localized string found for: {} for Locale.{}".format(in_str, lang.upper()))
         else:
             return val
     except Exception as e:
