@@ -26,14 +26,46 @@ from arjuna.tpi.constant import *
 
 class TestGroup:
 
-    def __init__(self, *, name, config, session, stage, im=None, em=None, it=None, et=None):
+    def __init__(self, *, name, config, session, stage, rules=None):
         self.__name = name
         self.__session = session
         self.__stage = stage
         self.__config = config
         self.__thname = None
         self.__dry_run = session.dry_run
-        self.__filters = {'im' : im, 'em': em, 'it': it, 'et': et}
+        self.__rules = rules
+        self.__css_path = config.value(ArjunaOption.ARJUNA_ROOT_DIR) + "/arjuna/res/arjuna.css" 
+
+    @classmethod
+    def create_rule_strs(cls, include_exclude_dict):
+        pickers_rulestr = {
+            'ip': "package *= {}",
+            'ep': "package *= {}",
+            'im': "module *= {}",
+            'em': "module *= {}",
+            'it': "name *= {}",
+            'et': "name *= {}",
+        }
+
+        rules = {'ir': [], 'er': []}
+
+        def remove_py_ext(name):
+            if not name.lower().endswith(".py"):
+                return name
+            else:
+                return name.replace(".py","")
+
+        for picker in pickers_rulestr:
+            names = include_exclude_dict.pop(picker)
+            if names:
+                for name in names:
+                    if picker in {'im', 'em'}:
+                        remove_py_ext(name)
+                    if picker.startswith('i'):
+                        rules['ir'].append(pickers_rulestr[picker].format(name))
+                    else:
+                        rules['er'].append(pickers_rulestr[picker].format(name))
+        return rules
 
     @property
     def config(self):
@@ -73,7 +105,7 @@ class TestGroup:
         self.__tests_dir = self.config.value(ArjunaOption.TESTS_DIR)
         suffix = ""
         if self.__name != "mgroup":
-            suffix = "-" + self.thread_name + "-" + self.__name
+            suffix = "-" + self.__session.name + "-" + self.__stage.name + "-" + self.__name
         self.__xml_path = os.path.join(self.config.value(ArjunaOption.REPORT_XML_DIR), "report{}.xml".format(suffix))
         self.__html_path = os.path.join(self.config.value(ArjunaOption.REPORT_HTML_DIR), "report{}.html".format(suffix))
         self.__report_formats = self.config.value(ArjunaOption.REPORT_FORMATS)
@@ -82,64 +114,23 @@ class TestGroup:
         pytest_ini_path = res_path + "/pytest.ini"
 
         # -s is to print to console.
-        self.__pytest_args = ["-c", pytest_ini_path, "--rootdir", self.__project_dir, "--no-print-logs", "--show-capture", "all", "--disable-warnings"] # 
+        self.__pytest_args = ["-c", pytest_ini_path, "--rootdir", self.__project_dir, "--no-print-logs", "--show-capture", "all", "--disable-warnings", "-rxX", "--css", self.__css_path] # 
         self.__test_args = []
-        self.__load_tests(**self.__filters)
+        self.__load_tests(rules=self.__rules)
         self.__load_meta_args()
 
+    def __load_tests(self, *, rules):
+        from arjuna import Arjuna
+        from arjuna.engine.selection.selector import Selector
+        selector = Selector()
+        if rules:
+            for rule in rules['ir']:
+                selector.include(rule)
+            for rule in rules['er']:
+                selector.exclude(rule)
+            
 
-    def __load_tests(self, *, im=None, em=None, it=None, et=None):
-        if im is None and em is None and it is None and et is None:
-            self.__load_all_tests()
-        else:
-            self.__load_tests_from_pickers(im=im, em=em, it=it, et=et)
-
-    def __load_all_tests(self):
-        self.__pytest_args.insert(0, self.tests_dir)
-
-    def __load_tests_from_pickers(self, *, im=None, em=None, it=None, et=None):  
-
-        def process_modules(ms):
-            ms = [m.replace(".py", "").replace("*","").replace("/", " and ").replace("\\", " and ") for m in ms]
-            return ["and" in m and "({})".format(m) or m for m in ms]
-
-        k_args = []
-
-        k_flag = False
-
-        if em:            
-            em = process_modules(em)
-            k_args.append(" and ".join(["not " + m for m in em]))
-            k_flag = True
-
-        # if ic:
-        #     prefix = k_flag and " and " or ""
-        #     k_args.append(prefix + " and ".join(["not " + c for c in ic]))
-        #     k_flag = True
-
-        if et:
-            prefix = k_flag and " and " or ""
-            k_args.append(prefix + " and ".join(["not " + c for c in et]))
-            k_flag = True
-
-        if im:
-            prefix = k_flag and " and " or ""            
-            cm = process_modules(im)
-            k_args.append(prefix + " or ".join(im))
-            k_flag = True
-
-        # if cc:
-        #     prefix = k_flag and " and " or "" 
-        #     k_args.append(prefix + " or ".join(cc))
-        #     k_flag = True
-
-        if it:
-            prefix = k_flag and " and " or "" 
-            k_args.append(prefix + " or ".join(it))
-            k_flag = True
-
-        if k_flag:
-            self.__test_args.append("-k " + "".join(k_args))
+        Arjuna.register_test_selector_for_group(selector)
 
     def __load_meta_args(self):
         pytest_report_args = []
@@ -153,43 +144,61 @@ class TestGroup:
         self.__pytest_args.extend(pytest_report_args)
         self.__pytest_args.extend(self.__test_args)
 
-        if self.__dry_run is not False:
+        if self.__dry_run not in {False, None}:
+            print("!!!!!! This is a DRY RUN !!!!!!!")
             if self.__dry_run == DryRunType.SHOW_TESTS:
+                print("Dry Run Type: SHOW TESTS")
+                print("You can see the test functions which will be executed as per settings of your command.")
                 self.__pytest_args.extend(["--collect-only"])
             elif self.__dry_run == DryRunType.SHOW_PLAN:
+                print("Dry Run Type: SHOW PLAN")
+                print("You can see the test functions as well as the fixtures which will be executed as per settings of your command.")
                 self.__pytest_args.extend(["--setup-plan"])
-            elif self.__dry_run == DryRunType.RUN_FIXTURES:
+            elif self.__dry_run == DryRunType.CREATE_RES:
+                print("Dry Run Type: CREATE RESOURCES")
+                print("All resources will be created as per your current command. You can see the test functions which will be executed as per settings of your command.")
                 self.__pytest_args.extend(["--setup-only"])
 
     def __str__(self):
-        return "Command: config={}, group={}, pickers={}".format(self.config.name, self.__name, self.__filters)
+        return "TestGroup: name:{}, config={}, rules={}".format(self.__name, self.config.name, self.__rules)
 
 
 class YamlTestGroup(TestGroup):
 
     def __init__(self, *, group_yaml, session, stage):
         self.__config = stage.config
-        self.__filters = {
-            'im': None,
-            'em': None,
-            'it': None,
-            'et': None
-        }
+        self.__rules = {'ir': [], 'er': []}
         self.__process_yaml(group_yaml)
-        super().__init__(name=group_yaml.name, config=self.__config, session=session, stage=stage, **self.__filters)
+        super().__init__(name=group_yaml.name, config=self.__config, session=session, stage=stage, rules=self.__rules)
 
     def __process_yaml(self, group_yaml):
         from arjuna import Arjuna
         for gmd_name in group_yaml.section_names:
-            if gmd_name.lower() == "conf":
+            pickers = {
+                'ip': None,
+                'ep': None,
+                'im': None,
+                'em': None,
+                'it': None,
+                'et': None,
+            }
+            gmd_name = gmd_name.lower()
+            if gmd_name == "conf":
                 self.__config = Arjuna.get_config(group_yaml.get_value("conf"))
-            elif gmd_name.lower() in {'im', 'em', 'it', 'et'}:
-                self.__filters[gmd_name.lower()] = group_yaml.get_value(gmd_name)
+            elif gmd_name in pickers:
+                pickers[gmd_name] = group_yaml.get_value(gmd_name)
+                if gmd_name.startswith('i'):
+                    self.__rules['ir'].extend(TestGroup.create_rule_strs(pickers)['ir'])
+                else:
+                    self.__rules['er'].extend(TestGroup.create_rule_strs(pickers)['er'])
+            elif gmd_name in {'ir', 'er'}:
+                self.__rules[gmd_name].extend(group_yaml.get_value(gmd_name))
+
 
 class MagicTestGroup(TestGroup):
 
-    def __init__(self, *, session, stage, im=None, em=None, it=None, et=None):
-        super().__init__(name="mgroup", config=stage.config, session=session, stage=stage, im=im, em=em, it=it, et=et)
+    def __init__(self, *, session, stage, rules=None):
+        super().__init__(name="mgroup", config=stage.config, session=session, stage=stage, rules=rules)
 
 
 class TestGroups:
