@@ -25,7 +25,10 @@ Arjuna Exceptions
 This module defines Exception classes that represent different types of run-time issues that can happen. The exceptions encapsulate the underlying exception message and stack traces.
 '''
 
+import threading
+
 from arjuna.core.error import *
+from arjuna.core.utils.obj_utils import get_function_meta_data
 
 class UndefinedConfigError(Exception):
     '''
@@ -121,15 +124,25 @@ class GuiLabelNotPresentError(Exception):
     def __init__(self, gns_name, label, context=None, msg=None):
         msg = msg is None and "" or msg
         context_msg = context and  " for context {}".format(context) or ""
-        super().__init__(f"No session definition exisits for name {name} in {session_yaml}")
+        super().__init__(f"No session definition exisits for name {label} in {gns_name}, {context} {msg}")
+
+
+class TestSessionsFileNotFoundError(Exception):
+    '''
+        Raised when `run-session` CLI sommand is used and sessions.yaml does not exist in `<Project Root Dir>/config` directory.
+    '''
+
+    def __init__(self, *, file_path):
+        super().__init__(f"Test sessions configuration file does not exist at {file_path}.")
+
 
 class UndefinedTestSessionError(Exception):
     '''
         Raised when there is no definition for a name used as test session name.
     '''
 
-    def __init__(self, *, session_name, sessions_file_path):
-        super().__init__(f"No session definition exists for name >>{session_name}<< in sessions configuration file at {sessions_file_path}")
+    def __init__(self, *, name, file_path):
+        super().__init__(f"No session definition exists for name >>{name}<< in sessions configuration file at {file_path}.")
 
 class InvalidTestSessionDefError(Exception):
     '''
@@ -137,4 +150,87 @@ class InvalidTestSessionDefError(Exception):
     '''
 
     def __init__(self, *, session_name, sessions_file_path, msg):
-        super().__init__(f"Invalid session definition for >>{session_name}<< in sessions file {sessions_file_path}. {msg}")
\ No newline at end of file
+        super().__init__(f"Invalid session definition for >>{session_name}<< in sessions file {sessions_file_path}. {msg}")
+
+class TestStagesFileNotFoundError(Exception):
+    '''
+        Raised when there `run-session/run-stage` CLI sommand is used and stages.yaml is does not exist in `<Project Root Dir>/config` directory.
+    '''
+
+    def __init__(self, *, file_path):
+        super().__init__(f"Test Stages configuration file does not exist at {file_path}.")
+
+class UndefinedTestStageError(Exception):
+    '''
+        Raised when there is no definition for a name used as test stage name.
+    '''
+
+    def __init__(self, *, name, file_path):
+        super().__init__(f"No stage definition exists for name >>{name}<< in stages configuration file at {file_path}")
+
+
+class InvalidTestStageDefError(Exception):
+    '''
+        Raised when there is an error in the definition of a test stage.
+    '''
+
+    def __init__(self, *, session_name, stage_name, stages_file_path, msg):
+        super().__init__(f"Invalid stage definition for >>{stage_name}<< in stages file {stages_file_path}. It is referred in session >>{session_name}<<. {msg}")
+
+class TestGroupsFileNotFoundError(Exception):
+    '''
+        Raised when there `run-session/run-stage/run-group` CLI sommand is used and `groups.yaml` does not exist at `<Project Root Dir>/config` directory.
+    '''
+
+    def __init__(self, *, file_path):
+        super().__init__(f"Test groups configuration file does not exist at {file_path}.")
+
+class UndefinedTestGroupError(Exception):
+    '''
+        Raised when there is no definition for a name used as test group name.
+    '''
+
+    def __init__(self, *, name, file_path):
+        super().__init__(f"No group definition exists for name >>{name}<< in groups configuration file at {file_path}")
+
+class TestSelectorNotFoundError(Exception):
+    '''
+        Test Selector object was not found for current thread (and for current test group creation.)
+
+        Every Test Group is run in a thread either sequentially or parallely.
+
+        A Test Selector object is supposed to be created for every test group.
+
+        This exception is raised when Arjuna is not able to find the registered test Selector object for current thread.
+    '''
+
+    def __init__(self):
+        super().__init__("No test Selector object was found for current test group in thread: {}".format(threading.current_thread().name))
+
+
+class TestDecoratorError(Exception):
+    '''
+        Raised when there is an error in @test decorator for a given test function.
+    '''
+
+    def __init__(self, func_qual_name, msg):
+        super().__init__(f"There is an error in @test decoratior for {func_qual_name}. {msg}")
+
+
+class HttpUnexpectedStatusCode(Exception):
+    '''
+        Raised when the HTTP status code for a request does not match expected status code(s).
+    '''
+
+    def __init__(self, request, response):
+        super().__init__(f"Unexpected status code {response.status_code} for {response.url} in {request.method} request.")
+        self.__request = request
+        self.__response = response
+
+    @property
+    def request(self):
+        return self.__request
+
+    @property
+    def response(self):
+        return self.__response
