@@ -23,7 +23,7 @@ Contains many general purpose type abstractions.
 
 import abc
 import pprint
-from collections import OrderedDict
+from collections import OrderedDict, namedtuple
 from typing import Callable
 import abc
 
@@ -74,7 +74,7 @@ class _ArDict(metaclass=abc.ABCMeta):
         return self.__store.keys()
 
     def __getattr__(self, attr):
-        return getattr(self.__store, attr)
+        return self.__store[attr]
 
     def __len__(self):
         return len(self.__store.keys())
@@ -103,7 +103,7 @@ class CIStringDict(_ArDict):
         Dictionary with case-insensitive keys.
 
         Arguments:
-            pydict: (Optional) A `dict` object.
+            pydict: (Optional) A **dict** object.
     '''
     def __init__(self, pydict={}):
         super().__init__(pydict)
@@ -114,6 +114,9 @@ class CIStringDict(_ArDict):
     def _clone(self):
         return CIStringDict(self.__store)
 
+    def __str__(self):
+        return "CIStringDict: " + super().__str__()
+        
 
 class ProcessedKeyDict(_ArDict):
     '''
@@ -121,7 +124,7 @@ class ProcessedKeyDict(_ArDict):
 
         Arguments:
             processor: A callable for processing the dictionary key.
-            pydict: (Optional) A `dict` object.
+            pydict: (Optional) A **dict** object.
     '''
 
     def __init__(self, *, processor: Callable, pydict: dict={}):
@@ -134,14 +137,14 @@ class ProcessedKeyDict(_ArDict):
     def _clone(self):
         return ProcessedKeyDict(self.__processor, self.__store)  
 
-@track("trace")
+@track("debug")
 class OnceOnlyKeyCIStringDict(CIStringDict):
     '''
         Dictionary with case-insensitive keys that allows for immutable key-value pairs.
 
         Arguments:
             processor: A callable for processing the dictionary key.
-            pydict: (Optional) A `dict` object.
+            pydict: (Optional) A **dict** object.
     '''
 
     def __init__(self, d={}):
@@ -168,7 +171,7 @@ class OnceOnlyKeyCIStringDict(CIStringDict):
 @track("debug")
 class Dictable(metaclass=abc.ABCMeta):
     '''
-        Abstract class. Any object which has a method `as_dict` is a `Dictable`.
+        Abstract class. Any object which has a method **as_dict** is a **Dictable**.
     '''
 
     @abc.abstractmethod
@@ -180,7 +183,7 @@ class Dictable(metaclass=abc.ABCMeta):
             Dictionary representation of this object.
 
             Returns:
-                A `dict` object.
+                A **dict** object.
         '''
         retval = self._as_dict()
         if type(retval) is not dict:
@@ -212,7 +215,7 @@ class Point(Dictable):
 
 class Offset(Point):
     '''
-        Represents an offset from current `Point` on `Screen` in terms of XY coordinates.
+        Represents an offset from current **Point** on **Screen** in terms of XY coordinates.
 
         Args:
             x: X co-ordinate
@@ -231,21 +234,21 @@ class Screen:
     @staticmethod
     def xy(x:int, y:int) -> Point:
         '''
-            Create a `Point` on Gui Screen in terms of its XY coordinates.
+            Create a **Point** on Gui Screen in terms of its XY coordinates.
         '''
         return _Point(x,y)
 
     @staticmethod
     def offset(x, y) -> Offset:
         '''
-            Create a `Offset` on Gui Screen in terms of its XY coordinates.
+            Create a **Offset** on Gui Screen in terms of its XY coordinates.
         '''
         return _Offset(x,y)
 
 @track("debug")
 class NVPair(Dictable):
     '''
-        Encapsulates a name-value pair. It is an implementation of `Dictable`.
+        Encapsulates a name-value pair. It is an implementation of **Dictable**.
 
         Args:
             name: Name of this object
@@ -263,7 +266,7 @@ class NVPair(Dictable):
 @track("debug")
 class Attr(NVPair):
     '''
-        A name-value pair with an associated optional tag name. It is an implementation of `Dictable`.
+        A name-value pair with an associated optional tag name. It is an implementation of **Dictable**.
 
         Keyword Arguments:
             name: (Mandatory) Name of this object
@@ -284,7 +287,7 @@ class Attr(NVPair):
 @track("debug")
 class NVPairs(Dictable):
     '''
-        Encapsulates arbitrary name-value pairs. It is an implementation of `Dictable`.
+        Encapsulates arbitrary name-value pairs. It is an implementation of **Dictable**.
 
         Keyword Arguments:
             **nvpairs: Arbitrary name-value pairs passed as keyword arguments.
@@ -294,4 +297,7 @@ class NVPairs(Dictable):
         self.__kwargs = nvpairs
 
     def _as_dict(self):
-        return self.__kwargs
\ No newline at end of file
+        return self.__kwargs
+
+
+NetworkPacketInfo = namedtuple("NetworkPacketInfo", "label request response redir_network_packets")
\ No newline at end of file
